@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::GenPericmdScript;
 
-our $DATE = '2016-10-27'; # DATE
-our $VERSION = '0.33'; # VERSION
+our $DATE = '2016-12-15'; # DATE
+our $VERSION = '0.34'; # VERSION
 
 use 5.010001;
 use strict;
@@ -46,6 +46,7 @@ has code_after_end => (is=>'rw');
 has default_format => (is=>'rw');
 has skip_format => (is=>'rw');
 has use_utf8 => (is=>'rw');
+has default_dry_run => (is=>'rw');
 has allow_prereq => (is=>'rw');
 has per_arg_json => (is=>'rw');
 has per_arg_yaml => (is=>'rw');
@@ -153,6 +154,7 @@ sub munge_files {
             (default_format => $self->default_format) x !!$self->default_format,
             skip_format => $self->skip_format ? 1:0,
             use_utf8 => $self->use_utf8,
+            (default_dry_run => $self->default_dry_run) x !!defined($self->default_dry_run),
             (allow_prereq => $self->allow_prereq) x !!$self->allow_prereq,
             (per_arg_json => $self->per_arg_json) x !!defined($self->per_arg_json),
             (per_arg_yaml => $self->per_arg_yaml) x !!defined($self->per_arg_yaml),
@@ -248,7 +250,7 @@ Dist::Zilla::Plugin::GenPericmdScript - Generate Perinci::CmdLine script
 
 =head1 VERSION
 
-This document describes version 0.33 of Dist::Zilla::Plugin::GenPericmdScript (from Perl distribution Dist-Zilla-Plugin-GenPericmdScript), released on 2016-10-27.
+This document describes version 0.34 of Dist::Zilla::Plugin::GenPericmdScript (from Perl distribution Dist-Zilla-Plugin-GenPericmdScript), released on 2016-12-15.
 
 =head1 SYNOPSIS
 
@@ -440,7 +442,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Dist-Zilla
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Dist-Zilla-Plugin-Rinci-ScriptFromFunc>.
+Source repository is at L<https://github.com/perlancar/perl-Dist-Zilla-Plugin-GenPericmdScript>.
 
 =head1 BUGS
 
